@@ -10,6 +10,7 @@ import polars as pl
 import numpy as np
 import inspect
 import platform
+from flask import session
 import os
 import multiprocessing as mp
 from ServexTools.socket_manager import get_socketio
@@ -19,13 +20,6 @@ socketio = get_socketio()
 bp = Blueprint('Table', __name__)
 
 system = platform.system().lower()
-cpu_count = os.cpu_count() or 4
-
-try:
-    pl.threadpool_size(cpu_count)
-    # print(f"Polars configurado con {cpu_count} hilos para sistema {system}")
-except Exception as e:
-    pass
 
 COLUMNA = "NombreColumnas"
 DATO = "DatosColumnas"
@@ -77,7 +71,6 @@ def CrearTabla(
     ps_paginando=False,
     ps_conteo=0,
     ps_offset=0,
-    ps_uuid='',
     ps_func='',
     ps_current_active_page=1
 ):
@@ -121,9 +114,10 @@ def CrearTabla(
     Returns:
         str o tuple: HTML generado o tupla con HTML y totales según configuración
     """
-
-
-    
+    try:
+        ps_idusuario = session['idusuario']
+    except Exception:
+        ps_idusuario = 0
     if ColumnasJson:
         NombreColumnas = tuple(col[COLUMNA] for col in ColumnasJson)
         DatosColumnas = tuple(col[DATO] for col in ColumnasJson)
@@ -155,7 +149,6 @@ def CrearTabla(
     
     Datos_originales = None
     dt_conteo = 0
-    uuid_ps = ps_uuid  
     
     try:
         
@@ -181,9 +174,10 @@ def CrearTabla(
                 ruta_tabla_actual = inspect.stack()[1].function if ps_func == '' else ps_func
                 EscribirLog(f"Totales calculados para {ruta_tabla_actual}: {totales_completos}")
             
-            uuid_ps = insert_paginacion(
+            insert_paginacion(
                 RUTA_TABLA=inspect.stack()[1].function if ps_func == '' else ps_func,
                 datos=Datos_originales,
+                ps_idusuario = ps_idusuario,
                 longitud_paginacion=LongitudPaginacion,
                 parametros_tabla={
                     'NombreColumnas': NombreColumnas,
@@ -218,18 +212,24 @@ def CrearTabla(
             )
         
         elif ps_paginando and paginacion_server:
-            resultados = find_paginacion(ps_func, uuid_ps, ps_current_active_page)
-            
-            if resultados and 'paginas' in resultados:
-                
-                Datos_originales = resultados['paginas']
+            if ps_current_active_page > 1:
+                Datos_originales = Datos.copy() if isinstance(Datos, list) else []
                 dt_conteo = len(Datos_originales)
-                
-                
+                offset = ps_offset
+                limit = offset + LongitudPaginacion
+                Datos = Datos_originales[offset:limit] if dt_conteo > 0 else []
+                Datos_originales = Datos
+            else:
+                resultados = find_paginacion(ps_func, ps_idusuario, ps_current_active_page)
+                if resultados and 'paginas' in resultados:
+                    Datos_originales = resultados['paginas']
+                else:
+                    EscribirLog(f"No se encontraron datos para el ID de usuario: {ps_idusuario}")
+
+                dt_conteo = len(Datos_originales)
+
                 offset = (ps_current_active_page - 1) * LongitudPaginacion if ps_offset == 0 else ps_offset
                 limit = offset + LongitudPaginacion
-            else:
-                EscribirLog(f"No se encontraron datos para el UUID: {uuid_ps}")
     except Exception as e:
         EscribirLog(f"Error en paginación servidor: {str(e)}")
         
@@ -317,7 +317,7 @@ def CrearTabla(
             celdas_html = ""
             for i, col in enumerate(DatosColumnas):
                 valor = formatear_celda(i, col, row)
-                if TotalizarColumnas and not isinstance(TotalizarColumnas, bool) and TotalizarColumnas[i]:
+                if paginacion_server==False and TotalizarColumnas and not isinstance(TotalizarColumnas, bool) and TotalizarColumnas[i]:
                     Totales[f'T{col}'] += Tools.StrToFloat(valor)
                 celdas_html += f'<td id="{col}_{numerador}" class="{class_map[i]} text-wrap">{valor}</td>'
             
@@ -360,7 +360,6 @@ def CrearTabla(
         """
 
     if paginacion_server:
-        uuid_ps = uuid_ps if 'uuid_ps' in locals() else ps_uuid
         func = inspect.stack()[1].function if ps_func == '' else ps_func
         offset = ps_offset
         limit = offset + LongitudPaginacion
@@ -368,7 +367,7 @@ def CrearTabla(
 
         ScriptPaginacion = f"""
             async function {func}_ps(page) {{
-                var datos = {{ page: page, consulta: '{uuid_ps}' }};
+                var datos = {{ page: page, ps_idusuario: '{ps_idusuario}' }};
                 const data = await General.PostBackData(datos, '/{func}_ps');
                 if (data.Estatus == 'Exito') {{
                     AgregarHtml('#{iddivtable}', data.html);
@@ -589,202 +588,85 @@ def CondicionParaTotalizar(ColumnaTotales, SubColumnasDatos, DatosColumnas, row)
     valor = SubDatosMarcar(SubColumnasDatos, DatosColumnas, campoValidar, row)
     return valor != ValorValidar
 
-def ValidarLongitudDatos(*args):
-    """
-    Valida que todos los argumentos de tipo secuencia tengan la misma longitud.
-    
-    Verifica que todos los argumentos que no son False tengan exactamente la misma longitud,
-    lo que es crucial para el correcto funcionamiento de las funciones de generación de tablas.
-    
-    Args:
-        *args: Secuencias a validar (tuplas, listas, etc.)
-        
-    Raises:
-        ValueError: Si las longitudes de los argumentos no coinciden
-    """
-    lengths = [len(arg) for arg in args if arg is not False]
-    if len(set(lengths)) > 1:
-        raise ValueError("Las longitudes de los argumentos no coinciden")
+def ValidarLongitudDatos(NombreColumnas, DatosColumnas, ClassColumnas, FormatoColumnas, TotalizarColumnas, SubColumnasDatos):
+    if len(NombreColumnas) != len(DatosColumnas) or len(NombreColumnas) != len(ClassColumnas):
+        raise Exception("""Los datos enviados referente a las columnas (NombreColumnas, DatosColumnas y ClassColumnas) deben tener la misma cantidad de datos. 
+                        NombreColumnas Cantidad("""+str(len(NombreColumnas))+"""), DatosColumnas Cantidad("""+str(len(DatosColumnas))+""") y ClassColumnas Cantidad("""+str(len(ClassColumnas))+""")""")
 
-def _acceso_seguro(data, keys):
-    """
-    Proporciona acceso anidado seguro a diccionarios y listas para evitar excepciones.
-    
-    Permite navegar estructuras de datos anidadas (diccionarios y listas) de forma segura,
-    devolviendo un valor predeterminado cuando una clave no existe o el tipo de dato
-    no permite el acceso solicitado.
-    
-    Args:
-        data: Estructura de datos (diccionario o lista) a acceder
-        keys: Clave única o secuencia de claves para acceso anidado
-        
-    Returns:
-        Valor encontrado en la ruta especificada o cadena vacía si no existe
-    """
-    if not keys:
-        return data or ""
+    if FormatoColumnas != False:
+        if len(NombreColumnas) != len(FormatoColumnas):
+            raise Exception("""Los datos enviados referente a las columnas (NombreColumnas y FormatoColumnas) deben tener la misma cantidad de datos.
+                            NombreColumnas Cantidad("""+str(len(NombreColumnas))+""") y FormatoColumnas Cantidad("""+str(len(FormatoColumnas))+""")""")
 
-    if isinstance(keys, str):
-        return data.get(keys, "")
-
-    valor = data
-    for k in keys:
-        if isinstance(valor, dict):
-            valor = valor.get(k, "")
-        elif isinstance(valor, list):
-            if isinstance(k, int) and 0 <= k < len(valor):
-                valor = valor[k]
-            else:
-                valor = next((item[k] for item in valor if isinstance(item, dict) and k in item), "")
-        else:
-            return ""
-    return valor
+    if TotalizarColumnas != False:
+        if len(NombreColumnas) != len(TotalizarColumnas):
+            raise Exception("""Los datos enviados referente a las columnas (NombreColumnas y TotalizarColumnas) deben tener la misma cantidad de datos. 
+                             NombreColumnas Cantidad("""+str(len(NombreColumnas))+""") y TotalizarColumnas Cantidad("""+str(len(TotalizarColumnas))+""")""")
+    if SubColumnasDatos != False:
+        if len(NombreColumnas) != len(SubColumnasDatos):
+            raise Exception("""Los datos enviados referente a las columnas (NombreColumnas y SubColumnasDatos) deben tener la misma cantidad de datos. 
+                                NombreColumnas Cantidad("""+str(len(NombreColumnas))+""") y SubColumnasDatos Cantidad("""+str(len(SubColumnasDatos))+""")""")
 
 def ProcesarSubDatos(SubColumnasDatos, countCol, col, row):
-    """Procesamiento optimizado y simplificado de datos anidados"""
-    # Caso simple: no hay subdatos o configuración inválida
-    if not SubColumnasDatos or SubColumnasDatos is False:
-        return row.get(col, "")
-    
-    tup = SubColumnasDatos[countCol] if countCol < len(SubColumnasDatos) else False
-    if not tup or tup is False:
-        return row.get(col, "")
-    
-    # -----------------------------------------------------------
-    # ACCESO SIMPLIFICADO Y OPTIMIZADO
-    # -----------------------------------------------------------
-    
-    # Caso 1: Tupla de 4 elementos (tres niveles)
-    if len(tup) == 4:
-        # Camino feliz: acceso directo a tres niveles
-        try:
-            return row[tup[0]][tup[1]][tup[2]]
-        except (KeyError, TypeError, IndexError):
-            pass
-            
-        # Verificar si hay marcador especial
-        try:
-            columna = tup[3]
-            if '<' in columna:
-                campo_alt = columna.split('<')[1]
-                if campo_alt in row:
-                    return row[campo_alt]
-        except (IndexError, AttributeError):
-            pass
-        
-        # Estrategia de navegación por tipo
-        try:
-            # Usar pandas para campos de primer nivel que puedan ser DataFrame o Series
-            if isinstance(row.get(tup[0]), (pd.DataFrame, pd.Series)):
-                # Usar .loc o .at para acceso rápido a datos
-                campo_pd = row[tup[0]]
-                if tup[1] in campo_pd and tup[2] in campo_pd:
-                    return campo_pd.at[tup[1], tup[2]]
-            
-            # Para diccionarios anidados
-            primer_nivel = row.get(tup[0], {})
-            if isinstance(primer_nivel, dict):
-                segundo_nivel = primer_nivel.get(tup[1], {})
-                if isinstance(segundo_nivel, dict):
-                    return segundo_nivel.get(tup[2], tup[2])
-                elif isinstance(segundo_nivel, list):
-                    # Buscar en lista
-                    for item in segundo_nivel:
-                        if isinstance(item, dict) and tup[2] in item:
-                            return item[tup[2]]
-            
-            # Para listas en el primer nivel
-            elif isinstance(primer_nivel, list):
-                # Usar numpy para buscar en listas grandes si es posible
-                if len(primer_nivel) > 100 and all(isinstance(x, dict) for x in primer_nivel[:10]):
+    columna = ""
+    if SubColumnasDatos != False:
+        tup = SubColumnasDatos[countCol]
+        if tup != False:
+            if len(tup) == 4:
+                try:
+                    columna = row[tup[0]][tup[1]][tup[2]]
+                except Exception as ex:
                     try:
-                        # Convertir a DataFrame para búsqueda vectorizada
-                        df_temp = pd.DataFrame(primer_nivel)
-                        if tup[1] in df_temp.columns:
-                            resultado = df_temp[df_temp[tup[1]] == tup[2]]
-                            if not resultado.empty:
-                                return resultado.iloc[0].get(tup[2], tup[2])
-                    except Exception:
-                        pass
-                
-                # Fallback a búsqueda tradicional
-                for item in primer_nivel:
-                    if isinstance(item, dict):
-                        if tup[1] in item:
-                            segundo_nivel = item[tup[1]]
-                            if isinstance(segundo_nivel, dict) and tup[2] in segundo_nivel:
-                                return segundo_nivel[tup[2]]
-        except Exception:
-            pass
-        
-        # Valor por defecto
-        return tup[2]
-    
-    # Caso 2: Tupla de 2-3 elementos (dos niveles)
+                        columna = tup[3]
+                        if columna.count('<'):
+                            columnanombre = tup[3].split('<')
+                            columna = row[columnanombre[1]]
+                        PCampo = row[tup[0]]
+                        formato = type(PCampo).__name__
+
+                        if formato == 'dict':
+                            SCampo = PCampo[tup[1]]
+                            formato2 = type(SCampo).__name__
+                            if formato2 == 'dict':
+                                columna = SCampo[tup[2]]
+                            elif formato2 == 'list':
+                                for Json in SCampo:
+                                    columna = Json[tup[2]]
+
+                        elif formato == 'list':
+                            for Json in PCampo:
+                                SCampo = Json[tup[1]]
+
+                                formato2 = type(SCampo).__name__
+                                if formato2 == 'dict':
+                                    columna = SCampo[tup[2]]
+                                elif formato2 == 'list':
+                                    for Json in SCampo:
+                                        columna = Json[tup[2]]
+
+                    except Exception as ex:
+                        columna = tup[2]
+            else:
+                try:
+                    columna = row[tup[0]][tup[1]]
+                except Exception as ex:
+                    try:
+                        columna = tup[2]
+                        if columna.count('<'):
+                            columnanombre = tup[2].split('<')
+                            columna = row[columnanombre[1]]
+
+                        for Json in row[tup[0]]:
+                            columna = Json[tup[1]]
+                    except Exception as ex:
+                        columna = tup[2]
+        else:
+            columna = row[col]
     else:
-        # Intento directo primero
-        try:
-            return row[tup[0]][tup[1]]
-        except (KeyError, TypeError, IndexError):
-            pass
-            
-        # Verificar si hay campo alternativo
-        try:
-            if len(tup) >= 3:
-                columna = tup[2]
-                if columna and '<' in columna:
-                    campo_alt = columna.split('<')[1]
-                    if campo_alt in row:
-                        return row[campo_alt]
-        except Exception:
-            pass
-        
-        # Buscar en campo tipo lista
-        try:
-            lista_campo = row.get(tup[0], [])
-            if isinstance(lista_campo, list):
-                # Optimización para listas grandes
-                if len(lista_campo) > 50 and all(isinstance(x, dict) for x in lista_campo[:5]):
-                    # Usar polars para búsqueda vectorizada
-                    try:
-                        df_temp = pl.DataFrame(lista_campo)
-                        if tup[1] in df_temp.columns:
-                            return df_temp.iloc[0].get(tup[1], "")
-                    except Exception:
-                        pass
-                        
-                # Búsqueda tradicional en lista
-                for item in lista_campo:
-                    if isinstance(item, dict) and tup[1] in item:
-                        return item[tup[1]]
-        except Exception:
-            pass
-        
-        # Valor por defecto según longitud de tupla
-        return tup[2] if len(tup) >= 3 else ""
-
-
-
-
-@lru_cache(maxsize=128)
-def _find_column_index(DatosColumnas, col):
-    """
-    Encuentra el índice de una columna en DatosColumnas con optimización de caché.
+        columna = row[col]
     
-    Busca el índice de una columna en una tupla de nombres de columnas,
-    utilizando caché para mejorar el rendimiento en búsquedas repetidas.
-    
-    Args:
-        DatosColumnas: Tupla con los nombres de las columnas
-        col: Nombre de la columna a buscar
-        
-    Returns:
-        int: Índice de la columna si se encuentra, -1 si no existe
-    """
-    try:
-        return DatosColumnas.index(col)
-    except ValueError:
-        return -1
+    return columna
+
 
 def SubDatosMarcar(SubColumnasDatos, DatosColumnas, col, row):
     """
@@ -1476,88 +1358,13 @@ def TableVacia(NombreColumnas=(), ColumnasJson=(),
     """
     return Html
 
-
-def _procesar_lote_simple(lote, columnas):
-    """
-    Procesa un lote de filas de forma simple y directa con optimización de memoria.
-    
-    Implementación básica que utiliza generadores para procesar datos sin cargar
-    todo el conjunto en memoria. Usado como fallback cuando fallan métodos más avanzados.
-    
-    Args:
-        lote: Lista de diccionarios con datos a procesar
-        columnas: Lista de nombres de columnas a extraer
-        
-    Yields:
-        dict: Diccionario con las columnas seleccionadas para cada fila
-    """
-    for row in lote:
-        yield {col: row.get(col, "") for col in columnas}
-
-def _procesar_lote_polars(lote, columnas):
-    """
-    Procesa un lote de filas usando Polars para vectorización y optimización de memoria.
-    
-    Utiliza la biblioteca Polars para procesamiento vectorizado de datos,
-    dividiendo el trabajo en chunks para reducir el uso de memoria y
-    mejorar el rendimiento con grandes conjuntos de datos.
-    
-    Args:
-        lote: Lista de diccionarios con datos a procesar
-        columnas: Lista de nombres de columnas a extraer
-        
-    Yields:
-        dict: Diccionario con las columnas seleccionadas para cada fila
-        
-    Notes:
-        Si ocurre un error, recurre al procesamiento simple como fallback
-    """
-    try:
-        df = pl.DataFrame(lote)
-        
-        for col in columnas:
-            if col not in df.columns:
-                df = df.with_columns(pl.lit("").alias(col))
-        
-        chunk_size = 1000
-        total_rows = len(df)
-        
-        for i in range(0, total_rows, chunk_size):
-            chunk = df.slice(i, min(chunk_size, total_rows - i))
-            for record in chunk.to_dicts():
-                yield record
-    except Exception as e:
-        yield from _procesar_lote_simple(lote, columnas)
-
-def procesar_datos_en_paralelo(datos, columnas, chunk_size=1000, max_workers=None):
-    """
-    Procesa datos en lotes para optimizar memoria y rendimiento.
-    
-    Divide los datos en lotes más pequeños y los procesa secuencialmente
-    utilizando Polars para vectorización. El nombre se mantiene por compatibilidad
-    aunque actualmente el procesamiento es secuencial.
-    
-    Args:
-        datos: Lista de diccionarios con todos los datos a procesar
-        columnas: Lista de nombres de columnas a extraer
-        chunk_size: Tamaño de cada lote para procesamiento
-        max_workers: Parámetro mantenido por compatibilidad (no utilizado)
-        
-    Yields:
-        dict: Diccionario con las columnas seleccionadas para cada fila
-    """
-    lotes = [datos[i:i+chunk_size] for i in range(0, len(datos), chunk_size)]
-    
-    for lote in lotes:
-        yield from _procesar_lote_polars(lote, columnas)
-
 @bp.route('/<RUTA_TABLA>_ps', methods = ['POST'])
 def PaginacionServer_ps(RUTA_TABLA):
     try:
         data = Tools.OptenerDatos(request)
         page: int = data['page']
-        consulta: str = data['consulta'] # el uuid por el que se va a buscar a la base de datos
-        dt_pagina = find_paginacion(RUTA_TABLA, consulta, page)
+        ps_idusuario: int = Tools.StrToInt(data['ps_idusuario']) # el idusuario por el que se va a buscar a la base de datos
+        dt_pagina = find_paginacion(RUTA_TABLA, ps_idusuario, page)
         datos = dt_pagina['paginas']
         
         # Verificar y eliminar ps_paginando para evitar duplicados
@@ -1579,7 +1386,6 @@ def PaginacionServer_ps(RUTA_TABLA):
         html = CrearTabla(
             datos,
             **parametros,
-            ps_uuid = consulta,
             ps_conteo = dt_pagina['total_conteo'],
             ps_func = RUTA_TABLA,  # Ya estamos usando el parámetro correcto de la función
             ps_current_active_page = page,
