@@ -513,7 +513,7 @@ def StrToByte(dato):
     except Exception as e:
         return 0
 
-def TiempoEspera(tiempo, IsGevent=True):
+def TiempoEspera(tiempo, IsGevent=False):
     """## Permite esperar un tiempo (float o int) y verifica periódicamente si existe el archivo .kill para salir inmediatamente."""
     import time
     check_interval = 0.01  # Intervalo de verificación en segundos
@@ -852,7 +852,7 @@ def FechaHora(AddDias=0.0,AddHoras=0.0,AddMinutos=0.0,AddSegundo=0.0):
     # fecha=datetime.now(tz=zona)+timedelta(days=AddDias,hours=AddHoras,minutes=AddMinutos,seconds=AddSegundo)
     if AddHoras>0.0 or AddHoras<0.0:
         AddMinutos+=AddHoras*60
-    fecha=StrToDateTime(Fecha(AddDias,AddHoras,AddMinutos,AddSegundo)+" "+Hora(AddMinutos,AddSegundo))
+    fecha=StrToDateTime(Fecha(AddDias=AddDias)+" "+Hora(AddMinutos,AddSegundo))
     return fecha
 
 def Fecha(AddDias=0.0,AddHoras=0.0,AddMinutos=0.0,AddSegundo=0.0):
@@ -941,8 +941,8 @@ def DesComprimir(RutaZip,RutaDescomprimir,eliminar=False):
     return RutaDescomprimir
 
 
-def EscribirLog(texto, tipo="Error",Consola=False):
-
+def EscribirLog(texto, tipo="Error"):
+        
     try:
         dia = datetime.now().day
         mes = datetime.now().month
@@ -954,19 +954,25 @@ def EscribirLog(texto, tipo="Error",Consola=False):
             os.mkdir(Directorio)
         mensajeActual = ""
         Url = Directorio+"/Success.log" if tipo != "Error" else Directorio+"/Error.log"
-        if Consola==True:
-            Url = Directorio+"/Consola.log"
-        creados=OptenerFechaArchivo(Url)
-        if CalDias(fechaInicial=creados)>=30:
-            DeleteFile(Url)
-        else:
-            zise=os.path.getsize(Url)
-            numero,medida=convert_size(zise)
-            if medida=="MB" and numero>10.0:
-                DeleteFile(Url)
+        try:
+            if ExistFile(Url):
+                creados=OptenerFechaArchivo(Url)
+                if CalDias(fechaInicial=creados)>=30:
+                    DeleteFile(Url)
+                else:
+                    zise=os.path.getsize(Url)
+                    numero,medida=convert_size(zise)
+                    if medida=="MB" and numero>10.0:
+                        DeleteFile(Url)
+            else:
+                CreateFile(Url,"")
+        except Exception as e:
+            print(str(e))
+            
         if ExistFile(Url):
             mensajeActual = ReadFile(Url)
-
+            
+            
         mensaje=tiempo + ": " + texto + "\n" + mensajeActual
         msjprint=tiempo + ": " + texto + "\n"
         print(msjprint)
@@ -974,7 +980,6 @@ def EscribirLog(texto, tipo="Error",Consola=False):
     except Exception as e:
         print(str(e))
 
-
 def CalDias(fechaInicial,FechaActual=datetime.now(),tiempoGratis=0):
     days=0
     diff_date = FechaActual - fechaInicial
